☰
Crate creed
Version 0.0.0
All Items
Re-exports
Modules
Macros
Structs
Enums
Traits
Functions
Type Definitions
?
Crate
creed
source
·
[
−
]
Re-exports
pub use error::
Error
;
Modules
driver
error
Macros
params
Structs
Connection
ConnectionEvent
ConnectionOptions
EventDispatcher
Parameter
Row
Enums
ParameterIndex
ParameterType
Parameters
Value
Traits
Event
Rows
Represents a row collection, collected from an executed statements It contains all the raw data from the executed query, being countable and iterable safely
Functions
xxx
Type Definitions
Async
AsyncResult
Result